==> fet-5.14.2.tar.bz2: fet-5.14.2/src/interface/modifyconstraintbasiccompulsorytimeform.h <==
/***************************************************************************
                          modifyconstraintbasiccompulsorytimeform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTBASICCOMPULSORYTIMEFORM_H
#define MODIFYCONSTRAINTBASICCOMPULSORYTIMEFORM_H

#include "ui_modifyconstraintbasiccompulsorytimeform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ModifyConstraintBasicCompulsoryTimeForm : public QDialog, Ui::ModifyConstraintBasicCompulsoryTimeForm_template  {
	Q_OBJECT
public:
	ConstraintBasicCompulsoryTime* _ctr;

	ModifyConstraintBasicCompulsoryTimeForm(ConstraintBasicCompulsoryTime* ctr);
	~ModifyConstraintBasicCompulsoryTimeForm();

public slots:
	void constraintChanged();
	void ok();
	void cancel();
};

#endif

==> fet_5.28.6.orig.tar.bz2: fet-5.28.6/src/interface/modifyconstraintbasiccompulsorytimeform.h <==
/***************************************************************************
                          modifyconstraintbasiccompulsorytimeform.h  -  description
                             -------------------
    begin                : Feb 10, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTBASICCOMPULSORYTIMEFORM_H
#define MODIFYCONSTRAINTBASICCOMPULSORYTIMEFORM_H

#include "ui_modifyconstraintbasiccompulsorytimeform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

class ModifyConstraintBasicCompulsoryTimeForm : public QDialog, Ui::ModifyConstraintBasicCompulsoryTimeForm_template  {
	Q_OBJECT
public:
	ConstraintBasicCompulsoryTime* _ctr;

	ModifyConstraintBasicCompulsoryTimeForm(QWidget* parent, ConstraintBasicCompulsoryTime* ctr);
	~ModifyConstraintBasicCompulsoryTimeForm();

public slots:
	void constraintChanged();
	void ok();
	void cancel();
};

#endif
